@@ -51,8 +51,9 @@ sock.listen(8080)
 
 conn = False
 
+print("Celestis server is listening at port 8080...\nTo close the server, visit http://localhost:8080 and then press Ctrl-C on the terminal")
+
 while True:
-    print("Celestis server is listening at port 8080...\nTo close the server, visit http://localhost:8080 and then press Ctrl-C on the terminal")
     conn, addr = sock.accept()
     request = conn.recv(1024).decode("utf-8")
     project_name = get_project_name()
@@ -86,7 +87,7 @@ def create_app(name):
     with open(urls_path, "w") as f:
         f.write("# urls for the {} app".format(name))
 
-    celestis_path = os.path.join(app_folder, "celestis.py")
+    celestis_path = os.path.join(app_folder, "server.py")
     with open(celestis_path, "w") as f:
         f.write(celestis_content)
     
